@@ -87,14 +87,18 @@ power.NTIDFDA <- function(alpha=0.05, theta1, theta2, theta0, CV, n,
                    r_const, ln_lBEL=log(theta1),ln_uBEL=log(theta2), alpha=alpha)
     
   if (details) {
-    cat(nsims,"sims. Time elapsed (sec):\n")
-    print(proc.time()-ptm)
-    cat("p(BE-ABE)=", p["BEabe"],"; p(BE-SABEc)=", p["BEul"],
-        "; p(BE-sratio)=", p["BEsratio"],"\n")
-    cat("\n")
+    ptm <- summary(proc.time()-ptm)
+    message(nsims,"sims. Time elapsed (sec): ", 
+            formatC(ptm["elapsed"], digits=2), "\n")
+    #print(ptm)
+    
+    # return power and components
+    names(p) <- c("p(BE)", "p(BE-sABEc)", "p(BE-ABE)", "p(BE-sratio)")
+    p
+  } else {
+    # return only the 'power'
+    as.numeric(p["BE"])
   }
-  # return the 'power'
-  as.numeric(p["BE"])
 }
 
 # working horse of RSABE for NTID's
@@ -108,7 +112,7 @@ power.NTIDFDA <- function(alpha=0.05, theta1, theta2, theta0, CV, n,
   Fval     <- qf(1-alpha, dfTT, dfRR, lower.tail=FALSE)
   
   counts   <- rep.int(0, times=4)
-  names(counts) <- c("BE", "BEsratio", "BEul","BEabe")
+  names(counts) <- c("BE", "BEul", "BEabe", "BEsratio")
   # to avoid memory problems for high number of sims
   # we are working with chunks of 1e7
   chunks   <- 1
@@ -144,6 +148,7 @@ power.NTIDFDA <- function(alpha=0.05, theta1, theta2, theta0, CV, n,
     Cm <- ifelse(abs(lCL)>abs(uCL),abs(lCL)^2,abs(uCL)^2)
     Cs <- Es*dfRR/chisqval    
     SABEc95 <- Em - Es + sqrt((Cm-Em)^2 + (Cs-Es)^2)
+    # what if no scaling has to be applied?
     BEscABE   <- (SABEc95 <= 0)
     # save memory
     rm(SEs, hw, Em, Es, Cm, Cs)
@@ -151,7 +156,7 @@ power.NTIDFDA <- function(alpha=0.05, theta1, theta2, theta0, CV, n,
     # upper limit of ratio swT/swR
     ul_sratio <- sqrt(s2wTs/s2wRs/Fval)
     # upper limit <= 2.5?
-    BEsratio  <- ul_sratio <= 2.5
+    BEsratio  <- (ul_sratio <= 2.5)
     
     counts["BEabe"]    <- counts["BEabe"]    + sum(BEABE)
     counts["BEul"]     <- counts["BEul"]     + sum(BEscABE)
